diff --git a/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs b/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
index 639f5c9b16..d5c8d5ccec 100644
--- a/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
+++ b/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
@@ -12,42 +12,42 @@ namespace osu.Game.Localisation.SkinComponents
///
/// "Sprite name"
///
- public static LocalisableString SpriteName => new TranslatableString(getKey(@"sprite_name"), "Sprite name");
+ public static LocalisableString SpriteName => new TranslatableString(getKey(@"sprite_name"), @"Sprite name");
///
/// "The filename of the sprite"
///
- public static LocalisableString SpriteNameDescription => new TranslatableString(getKey(@"sprite_name_description"), "The filename of the sprite");
+ public static LocalisableString SpriteNameDescription => new TranslatableString(getKey(@"sprite_name_description"), @"The filename of the sprite");
///
/// "Font"
///
- public static LocalisableString Font => new TranslatableString(getKey(@"font"), "Font");
+ public static LocalisableString Font => new TranslatableString(getKey(@"font"), @"Font");
///
/// "The font to use."
///
- public static LocalisableString FontDescription => new TranslatableString(getKey(@"font_description"), "The font to use.");
+ public static LocalisableString FontDescription => new TranslatableString(getKey(@"font_description"), @"The font to use.");
///
/// "Text"
///
- public static LocalisableString TextElementText => new TranslatableString(getKey(@"text_element_text"), "Text");
+ public static LocalisableString TextElementText => new TranslatableString(getKey(@"text_element_text"), @"Text");
///
/// "The text to be displayed."
///
- public static LocalisableString TextElementTextDescription => new TranslatableString(getKey(@"text_element_text_description"), "The text to be displayed.");
+ public static LocalisableString TextElementTextDescription => new TranslatableString(getKey(@"text_element_text_description"), @"The text to be displayed.");
///
/// "Corner radius"
///
- public static LocalisableString CornerRadius => new TranslatableString(getKey(@"corner_radius"), "Corner radius");
+ public static LocalisableString CornerRadius => new TranslatableString(getKey(@"corner_radius"), @"Corner radius");
///
/// "How rounded the corners should be."
///
- public static LocalisableString CornerRadiusDescription => new TranslatableString(getKey(@"corner_radius_description"), "How rounded the corners should be.");
+ public static LocalisableString CornerRadiusDescription => new TranslatableString(getKey(@"corner_radius_description"), @"How rounded the corners should be.");
///
/// "Show label"
@@ -55,10 +55,10 @@ namespace osu.Game.Localisation.SkinComponents
public static LocalisableString ShowLabel => new TranslatableString(getKey(@"show_label"), @"Show label");
///
/// "Whether the label should be shown."
///
- public static LocalisableString ShowLabelDescription => new TranslatableString(getKey(@"show_label_description"), @"Whether the label should be shown.");
+ public static LocalisableString ShowLabelDescription => new TranslatableString(getKey(@"show_label_description"), @"Whether the component's label should be shown.");
- private static string getKey(string key) => $"{prefix}:{key}";
+ private static string getKey(string key) => $@"{prefix}:{key}";
}
}
@@ -55,10 +55,10 @@ namespace osu.Game.Localisation.SkinComponents
public static LocalisableString ShowLabel => new TranslatableString(getKey(@"show_label"), @"Show label");
///
- /// "Whether the label should be shown."
+ /// "Whether the component's label should be shown."
///